generics: Imports from package 'NLP'

genericsR Documentation

Imports from package NLP

Description

The generics to access or modify the content or metadata of R objects provided by package NLP are re-exported by package tm for convenience. See meta for more information on the generics and meta.PlainTextDocument for the methods for getting and setting metadata provided by package tm.


tm documentation built on Oct. 1, 2026, 1:06 a.m.