powered by
Remove words from a text document.
removeWords(x, ...) # S3 method for character removeWords(x, words, ...) # S3 method for PlainTextDocument removeWords(x, ...)
The character or text document without the specified words.
A character or text document.
A character vector giving the words to be removed.
arguments to be passed to or from methods.
getTransformations to list available transformation (mapping) functions.
getTransformations
remove_stopwords provided by package tau.
remove_stopwords
data("crude") crude[[1]] removeWords(crude[[1]], stopwords("english"))
Run the code above in your browser using DataLab